.. _client_howtos:

***************************
How to Work with the Client
***************************

The following list hosts a series of brief how-to-guides focusing on 
the ``zenopy`` client and the authentication system behind it.

.. toctree::
    :maxdepth: 2
    :titlesonly:
    
    cli_token
    cli_config
    cli_client